Struct FrameDescription
Source pub struct FrameDescription<'a>(pub &'a [u8]);
A display adapter for one ULCP frame.
Values are summarized by length and never dumped, so callers can safely use
the result in logs even for secret-bearing property writes.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.