pub fn prop_are(buf: &mut [u8], tid: u8) -> Result<FrameWriter<'_>, WriteError>Expand description
Begin a CMD_PROP_ARE frame, to which the caller appends entries with
FrameWriter::write_entry and FrameWriter::write_status_entry.
pub fn prop_are(buf: &mut [u8], tid: u8) -> Result<FrameWriter<'_>, WriteError>Begin a CMD_PROP_ARE frame, to which the caller appends entries with
FrameWriter::write_entry and FrameWriter::write_status_entry.