pub struct PropertyNotification<'a> {
pub tid: u8,
pub kind: PropertyNotificationKind,
pub key: u32,
pub value: &'a [u8],
}Expand description
A validated property notification borrowing its value from the frame.
Fields
tid: u8kind: PropertyNotificationKindkey: u32value: &'a [u8]Implementations
Sourceimpl<'a> PropertyNotification<'a>
impl<'a> PropertyNotification<'a>
Sourcepub fn parse(bytes: &'a [u8]) -> Result<Self, PropertyNotificationError>
pub fn parse(bytes: &'a [u8]) -> Result<Self, PropertyNotificationError>
Parse exactly the three property notification commands accepted by a host session. Requests, streams, and unknown commands are rejected.
pub fn from_frame(frame: &Frame<'a>) -> Result<Self, PropertyNotificationError>